@@ -30,6 +30,8 @@ enum _ECellFlags {
 	E_CELL_ALIGN_RIGHT    = 1 << 2,
 
 	E_CELL_FOCUSED        = 1 << 3,
+
+	E_CELL_EDITING        = 1 << 4,
 };
 
 struct _ECell {
@@ -59,7 +61,7 @@ typedef struct {
 	void   	   (*draw)         (ECellView *ecell_view, GdkDrawable *drawable,
 	       			    int model_col, int view_col, int row,
 				    ECellFlags flags, int x1, int y1, int x2, int y2);
-	gint   	   (*event)        (ECellView *ecell_view, GdkEvent *event, int model_col, int view_col, int row);
+	gint   	   (*event)        (ECellView *ecell_view, GdkEvent *event, int model_col, int view_col, int row, ECellFlags flags);
 	void   	   (*focus)        (ECellView *ecell_view, int model_col, int view_col,
 				    int row, int x1, int y1, int x2, int y2);
 	void   	   (*unfocus)      (ECellView *ecell_view);
@@ -80,7 +82,7 @@ GtkType    e_cell_get_type  (void);
 ECellView *e_cell_new_view  (ECell *ecell, ETableModel *table_model, void *e_table_item_view);
 void       e_cell_kill_view (ECellView *ecell_view);
 
-void       e_cell_event     (ECellView *ecell_view, GdkEvent *event, int model_col, int view_col, int row);
+gint       e_cell_event     (ECellView *ecell_view, GdkEvent *event, int model_col, int view_col, int row, ECellFlags flags);
 
 void       e_cell_realize   (ECellView *ecell_view);
 void       e_cell_unrealize (ECellView *ecell_view);
