@@ -679,7 +679,7 @@ eti_table_model_row_changed (ETableModel *table_model, int row, ETableItem *eti)
 		return;
 	}
 
-	eti_request_region_redraw (eti, 0, row, eti->cols, row, 0);
+	eti_request_region_redraw (eti, 0, row, eti->cols - 1, row, 0);
 }
 
 static void
@@ -692,7 +692,7 @@ eti_table_model_cell_changed (ETableModel *table_model, int col, int row, ETable
 		return;
 	}
 
-	eti_request_region_redraw (eti, 0, row, eti->cols -1, row, 0);
+	eti_request_region_redraw (eti, 0, row, eti->cols - 1, row, 0);
 }
 
 static void
@@ -907,6 +907,10 @@ eti_destroy (GtkObject *object)
 
 	if (eti->tooltip->window)
 		gtk_widget_destroy (eti->tooltip->window);
+	if (eti->tooltip->timer) {
+		gtk_timeout_remove (eti->tooltip->timer);
+		eti->tooltip->timer = 0;
+	}
 	g_free (eti->tooltip);
 
 	if (GTK_OBJECT_CLASS (eti_parent_class)->destroy)
@@ -1039,6 +1043,9 @@ eti_init (GnomeCanvasItem *item)
 	eti->needs_compute_height = 0;
 
 	eti->tooltip = g_new0 (ETableTooltip, 1);
+	eti->tooltip->timer = 0;
+	eti->tooltip->window = NULL;
+	eti->tooltip->eti = GNOME_CANVAS_ITEM (eti);
 
 	e_canvas_item_set_reflow_callback (GNOME_CANVAS_ITEM (eti), eti_reflow);
 }
@@ -1331,8 +1338,9 @@ eti_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int width,
 	 * Draw focus
 	 */
 	if (f_found && eti->draw_focus){
+		gdk_gc_set_ts_origin (eti->focus_gc, f_x1, f_y1);
 		gdk_draw_rectangle (drawable, eti->focus_gc, FALSE,
-				    f_x1 + 1, f_y1, f_x2 - f_x1 - 2, f_y2 - f_y1 - 1);
+				    f_x1, f_y1, f_x2 - f_x1 - 1, f_y2 - f_y1 - 1);
 	}
 }
 
@@ -1467,7 +1475,6 @@ _do_tooltip (ETableItem *eti)
 	for (i = 0; i < eti->tooltip->row; i++)
 		y += (ETI_ROW_HEIGHT (eti, i) + 1);
 	eti->tooltip->y = y;
-	eti->tooltip->eti = GNOME_CANVAS_ITEM (eti);
 	eti->tooltip->row_height = ETI_ROW_HEIGHT (eti, i);
 	
 	e_cell_show_tooltip (ecell_view, 
@@ -1489,6 +1496,7 @@ eti_event (GnomeCanvasItem *item, GdkEvent *e)
 	switch (e->type){
 	case GDK_BUTTON_PRESS: {
 		double x1, y1;
+		GdkEventButton button;
 		int col, row;
 		gint cursor_row, cursor_col;
 
@@ -1506,15 +1514,22 @@ eti_event (GnomeCanvasItem *item, GdkEvent *e)
 			if (!find_cell (eti, e->button.x, e->button.y, &col, &row, &x1, &y1))
 				return TRUE;
 
-			return_val = FALSE;
-
-			gtk_signal_emit (GTK_OBJECT (eti), eti_signals [CLICK],
-					 row, col, e, &return_val);
+			ecell_view = eti->cell_views [col];
+			button = *(GdkEventButton *)e;
+			button.x = x1;
+			button.y = y1;
 
+			return_val = e_cell_event (ecell_view, (GdkEvent *) &button, view_to_model_col(eti, col), col, row, 0);
 			if (return_val)
 				return TRUE;
 
-			e_table_selection_model_do_something(eti->selection, view_to_model_row(eti, row), view_to_model_col(eti, col), e->button.state);
+			return_val = FALSE;
+			gtk_signal_emit (GTK_OBJECT (eti), eti_signals [CLICK],
+					 row, view_to_model_col(eti, col), &button, &return_val);
+			if (return_val)
+				return TRUE;
+
+			e_table_selection_model_do_something(eti->selection, view_to_model_row(eti, row), view_to_model_col(eti, col), button.state);
 
 			gtk_object_get(GTK_OBJECT(eti->selection),
 				       "cursor_row", &cursor_row,
@@ -1527,15 +1542,12 @@ eti_event (GnomeCanvasItem *item, GdkEvent *e)
 					e_table_item_enter_edit (eti, col, row);
 				}
 
-				ecell_view = eti->cell_views [col];
-				
 				/*
 				 * Adjust the event positions
 				 */
-				e->button.x = x1;
-				e->button.y = y1;
-				
-				e_cell_event (ecell_view, e, view_to_model_col(eti, col), col, row);
+
+				return_val = e_cell_event (ecell_view, (GdkEvent *) &button,
+							   view_to_model_col(eti, col), col, row, E_CELL_EDITING);
 			}
 
 			break;
@@ -1547,7 +1559,7 @@ eti_event (GnomeCanvasItem *item, GdkEvent *e)
 			e_table_selection_model_maybe_do_something(eti->selection, view_to_model_row(eti, row), view_to_model_col(eti, col), 0);
 			
 			gtk_signal_emit (GTK_OBJECT (eti), eti_signals [RIGHT_CLICK],
-					 row, col, e, &return_val);
+					 row, view_to_model_col(eti, col), e, &return_val);
 			break;
 		case 4:
 		case 5:
@@ -1594,7 +1606,8 @@ eti_event (GnomeCanvasItem *item, GdkEvent *e)
 				e->button.x = x1;
 				e->button.y = y1;
 
-				e_cell_event (ecell_view, e, view_to_model_col(eti, col), col, row);
+				return_val = e_cell_event (ecell_view, e,
+							   view_to_model_col(eti, col), col, row, E_CELL_EDITING);
 			}
 			break;
 		case 3:
@@ -1656,7 +1669,8 @@ eti_event (GnomeCanvasItem *item, GdkEvent *e)
 			e->motion.x = x1;
 			e->motion.y = y1;
 			
-			e_cell_event (ecell_view, e, view_to_model_col(eti, col), col, row);
+			return_val = e_cell_event (ecell_view, e,
+						   view_to_model_col(eti, col), col, row, E_CELL_EDITING);
 		}
 		break;
 	}
@@ -1745,7 +1759,9 @@ eti_event (GnomeCanvasItem *item, GdkEvent *e)
 				e_table_item_leave_edit (eti);
 #if 0
 				ecell_view = eti->cell_views [eti->editing_col];
-				e_cell_event (ecell_view, e, view_to_model_col(eti, eti->editing_col), eti->editing_col, eti->editing_row);
+				return_val = e_cell_event (ecell_view, e,
+							   view_to_model_col(eti, eti->editing_col),
+							   eti->editing_col, eti->editing_row, E_CELL_EDITING);
 #endif
 			}
 			return_val = FALSE;
@@ -1771,7 +1787,9 @@ eti_event (GnomeCanvasItem *item, GdkEvent *e)
 						 model_to_view_row(eti, cursor_row), cursor_col, e, &return_val);
 			} else {
 				ecell_view = eti->cell_views [eti->editing_col];
-				e_cell_event (ecell_view, e, view_to_model_col(eti, eti->editing_col), eti->editing_col, eti->editing_row);
+				return_val = e_cell_event (ecell_view, e,
+							   view_to_model_col(eti, eti->editing_col),
+							   eti->editing_col, eti->editing_row, E_CELL_EDITING);
 			}
 		}
 		break;
@@ -1790,7 +1808,9 @@ eti_event (GnomeCanvasItem *item, GdkEvent *e)
 
 		if (eti_editing (eti)){
 			ecell_view = eti->cell_views [eti->editing_col];
-			e_cell_event (ecell_view, e, view_to_model_col(eti, eti->editing_col), eti->editing_col, eti->editing_row);
+			return_val = e_cell_event (ecell_view, e,
+						   view_to_model_col(eti, eti->editing_col),
+						   eti->editing_col, eti->editing_row, E_CELL_EDITING);
 		}
 		break;
 	}
@@ -1799,6 +1819,7 @@ eti_event (GnomeCanvasItem *item, GdkEvent *e)
 	case GDK_ENTER_NOTIFY:
 		if (eti->tooltip->timer > 0)
 			gtk_timeout_remove (eti->tooltip->timer);
+		eti->tooltip->timer = 0;
 		break;
 
 	default:
