@@ -41,6 +41,7 @@ static GtkObjectClass *e_table_parent_class;
 
 enum {
 	CURSOR_CHANGE,
+	SELECTION_CHANGE,
 	DOUBLE_CLICK,
 	RIGHT_CLICK,
 	CLICK,
@@ -721,8 +722,8 @@ et_state_to_header (ETable *e_table, ETableHeader *full_header, ETableState *sta
 	return nh;
 }
 
-static void
-et_set_state(ETable *e_table, ETableState *state)
+void
+e_table_set_state_object(ETable *e_table, ETableState *state)
 {
 	if (e_table->header)
 		gtk_object_unref(GTK_OBJECT(e_table->header));
@@ -730,11 +731,21 @@ et_set_state(ETable *e_table, ETableState *state)
 	if (e_table->header)
 		gtk_object_ref(GTK_OBJECT(e_table->header));
 
-	if (e_table->sort_info)
+	if (e_table->sort_info) {
+		if (e_table->group_info_change_id)
+			gtk_signal_disconnect (GTK_OBJECT (e_table->sort_info),
+					       e_table->group_info_change_id);
 		gtk_object_unref(GTK_OBJECT(e_table->sort_info));
+	}
 	e_table->sort_info = state->sort_info;
-	if (e_table->sort_info)
+	if (e_table->sort_info) {
 		gtk_object_ref(GTK_OBJECT(e_table->sort_info));
+		e_table->group_info_change_id =
+			gtk_signal_connect (GTK_OBJECT (e_table->sort_info),
+					    "group_info_changed",
+					    GTK_SIGNAL_FUNC (sort_info_changed),
+					    e_table);
+	}
 
 	if (e_table->header_item)
 		gtk_object_set(GTK_OBJECT(e_table->header_item),
@@ -764,7 +775,7 @@ void            e_table_set_state                 (ETable               *e_table
 	e_table_state_load_from_string(state, state_str);
 
 	if (state->col_count > 0)
-		et_set_state(e_table, state);
+		e_table_set_state_object(e_table, state);
 
 	gtk_object_sink(GTK_OBJECT(state));
 }
@@ -782,7 +793,7 @@ void            e_table_load_state                (ETable               *e_table
 	e_table_state_load_from_file(state, filename);
 
 	if (state->col_count > 0)
-		et_set_state(e_table, state);
+		e_table_set_state_object(e_table, state);
 
 	gtk_object_sink(GTK_OBJECT(state));
 }
@@ -837,6 +848,12 @@ void            e_table_save_state                (ETable               *e_table
 	gtk_object_sink(GTK_OBJECT(state));
 }
 
+static void
+et_selection_model_selection_change (ETableGroup *etg, ETable *et)
+{
+	gtk_signal_emit (GTK_OBJECT (et),
+			 et_signals [SELECTION_CHANGE]);
+}
 
 static ETable *
 et_real_construct (ETable *e_table, ETableModel *etm, ETableExtras *ete,
@@ -880,6 +897,9 @@ et_real_construct (ETable *e_table, ETableModel *etm, ETableExtras *ete,
 			"sorter", e_table->sorter,
 			NULL);
 
+	gtk_signal_connect(GTK_OBJECT(e_table->selection), "selection_changed",
+			   GTK_SIGNAL_FUNC(et_selection_model_selection_change), e_table);
+
 	if (!specification->no_headers) {
 		e_table_setup_header (e_table);
 	}
@@ -1204,6 +1224,15 @@ e_table_selected_row_foreach     (ETable *e_table,
 					closure);
 }
 
+gint
+e_table_selected_count     (ETable *e_table)
+{
+	g_return_val_if_fail(e_table != NULL, -1);
+	g_return_val_if_fail(E_IS_TABLE(e_table), -1);
+
+	return e_table_selection_model_selected_count(e_table->selection);
+}
+
 void
 e_table_select_all (ETable *table)
 {
@@ -1887,25 +1916,26 @@ e_table_class_init (GtkObjectClass *object_class)
 
 	e_table_parent_class = gtk_type_class (PARENT_TYPE);
 
-	object_class->destroy   	 = et_destroy;
-	object_class->set_arg   	 = et_set_arg;
-	object_class->get_arg   	 = et_get_arg;
+	object_class->destroy           = et_destroy;
+	object_class->set_arg           = et_set_arg;
+	object_class->get_arg           = et_get_arg;
 
-	klass->cursor_change    	 = NULL;
-	klass->double_click     	 = NULL;
-	klass->right_click      	 = NULL;
-	klass->click            	 = NULL;
-	klass->key_press        	 = NULL;
+	klass->cursor_change            = NULL;
+	klass->selection_change         = NULL;
+	klass->double_click             = NULL;
+	klass->right_click              = NULL;
+	klass->click                    = NULL;
+	klass->key_press                = NULL;
 
-	klass->table_drag_begin           	 = NULL;
-	klass->table_drag_end             	 = NULL;
-	klass->table_drag_data_get        	 = NULL;
-	klass->table_drag_data_delete     	 = NULL;
+	klass->table_drag_begin         = NULL;
+	klass->table_drag_end           = NULL;
+	klass->table_drag_data_get      = NULL;
+	klass->table_drag_data_delete   = NULL;
 
-	klass->table_drag_leave                = NULL;
-	klass->table_drag_motion               = NULL;
-	klass->table_drag_drop                 = NULL;
-	klass->table_drag_data_received        = NULL;
+	klass->table_drag_leave         = NULL;
+	klass->table_drag_motion        = NULL;
+	klass->table_drag_drop          = NULL;
+	klass->table_drag_data_received = NULL;
 
 	et_signals [CURSOR_CHANGE] =
 		gtk_signal_new ("cursor_change",
@@ -1915,6 +1945,14 @@ e_table_class_init (GtkObjectClass *object_class)
 				gtk_marshal_NONE__INT,
 				GTK_TYPE_NONE, 1, GTK_TYPE_INT);
 
+	et_signals [SELECTION_CHANGE] =
+		gtk_signal_new ("selection_change",
+				GTK_RUN_LAST,
+				object_class->type,
+				GTK_SIGNAL_OFFSET (ETableClass, selection_change),
+				gtk_marshal_NONE__NONE,
+				GTK_TYPE_NONE, 0);
+
 	et_signals [DOUBLE_CLICK] =
 		gtk_signal_new ("double_click",
 				GTK_RUN_LAST,
