@@ -101,6 +101,7 @@ typedef struct {
 	GtkTableClass parent_class;
 
 	void        (*cursor_change)      (ETable *et, int row);
+	void        (*selection_change)   (ETable *et);
 	void        (*double_click)       (ETable *et, int row);
 	gint        (*right_click)        (ETable *et, int row, int col, GdkEvent *event);
 	gint        (*click)              (ETable *et, int row, int col, GdkEvent *event);
@@ -194,6 +195,8 @@ ETableState    *e_table_get_state_object          (ETable               *e_table
 /* note that it is more efficient to provide the state at creation time */
 void            e_table_set_state                 (ETable               *e_table,
 						   const gchar          *state);
+void            e_table_set_state_object          (ETable               *e_table,
+						   ETableState          *state);
 void            e_table_load_state                (ETable               *e_table,
 						   const gchar          *filename);
 
@@ -205,6 +208,7 @@ int             e_table_get_cursor_row            (ETable               *e_table
 void            e_table_selected_row_foreach      (ETable               *e_table,
 						   ETableForeachFunc     callback,
 						   gpointer              closure);
+gint            e_table_selected_count            (ETable               *e_table);
 EPrintable     *e_table_get_printable             (ETable               *e_table);
 
 gint            e_table_get_next_row              (ETable               *e_table,
