@@ -29,10 +29,24 @@
 
 #define PARENT_TYPE E_TABLE_MODEL_TYPE
 
+#define TREEPATH_CHUNK_AREA_SIZE (30 * sizeof (ETreePath))
+
 static ETableModel *e_tree_model_parent_class;
 
+struct ETreeModelPriv {
+	GMemChunk  *node_chunk;
+	ETreePath  *root;
+	gboolean    root_visible;
+	GArray     *row_array; /* used in the mapping between ETable and our tree */
+	GHashTable *expanded_state; /* used for loading/saving expanded state */
+	GString    *sort_group;	/* for caching the last sort group info */
+	gboolean    expanded_default; /* whether nodes are created expanded or collapsed by default */
+	gboolean   frozen;	/* has there been a pre-change event on us? */
+};
+
 struct ETreePath {
 	gboolean             expanded;
+	gboolean             expanded_set;
 	guint                visible_descendents;
 	char                *save_id;
 	ETreePathCompareFunc compare;
@@ -142,7 +156,11 @@ e_tree_path_unlink (ETreePath *path)
 void
 e_tree_model_node_traverse (ETreeModel *model, ETreePath *path, ETreePathFunc func, gpointer data)
 {
-	ETreePath *child = path->first_child;
+	ETreePath *child;
+
+	g_return_if_fail (path);
+
+	child = path->first_child;
 
 	while (child) {
 		ETreePath *next_child = child->next_sibling;
@@ -155,33 +173,49 @@ e_tree_model_node_traverse (ETreeModel *model, ETreePath *path, ETreePathFunc fu
 }
 
 
-/* virtual methods */
 
-static gboolean
-expanded_remove_func (gpointer key, gpointer value, gpointer user_data)
+void
+e_tree_model_freeze(ETreeModel *etm)
 {
-	g_free (key);
-	return TRUE;
+	ETreeModelPriv *priv = etm->priv;
+
+	priv->frozen = TRUE;
 }
 
+void
+e_tree_model_thaw(ETreeModel *etm)
+{
+	ETreeModelPriv *priv = etm->priv;
+
+	priv->frozen = FALSE;
+	e_table_model_changed(E_TABLE_MODEL(etm));
+}
+
+
+/* virtual methods */
+
 static void
 etree_destroy (GtkObject *object)
 {
 	ETreeModel *etree = E_TREE_MODEL (object);
+	ETreeModelPriv *priv = etree->priv;
 
 	/* XXX lots of stuff to free here */
-	g_array_free (etree->row_array, TRUE);
-	g_hash_table_foreach_remove (etree->expanded_state,
-				     expanded_remove_func, NULL);
+	g_array_free (priv->row_array, TRUE);
+	g_hash_table_destroy (priv->expanded_state);
+
+	g_string_free(priv->sort_group, TRUE);
+
+	g_free (priv);
 
-	g_string_free(etree->sort_group, TRUE);
 	GTK_OBJECT_CLASS (e_tree_model_parent_class)->destroy (object);
 }
 
 static ETreePath*
 etree_get_root (ETreeModel *etm)
 {
-	return etm->root;
+	ETreeModelPriv *priv = etm->priv;
+	return priv->root;
 }
 
 static ETreePath*
@@ -269,11 +303,14 @@ etree_is_visible (ETreeModel *etm, ETreePath* node)
 static void
 etree_set_expanded (ETreeModel *etm, ETreePath* node, gboolean expanded)
 {
+	ETreeModelPriv *priv = etm->priv;
 	ETreePath *child;
 	int row;
 
 	g_return_if_fail (node);
 
+	node->expanded_set = TRUE;
+
 	if (node->expanded == expanded)
 		return;
 
@@ -286,18 +323,7 @@ etree_set_expanded (ETreeModel *etm, ETreePath* node, gboolean expanded)
 
 	node->expanded = expanded;
 	if (node->save_id) {
-		g_hash_table_insert (etm->expanded_state, node->save_id, (gpointer)expanded);
-
-		if (expanded) {
-			/* the node previously was collapsed */
-			etm->num_collapsed_to_save --;
-			etm->num_expanded_to_save ++;
-		}
-		else {
-			/* the node previously was expanded */
-			etm->num_expanded_to_save --;
-			etm->num_collapsed_to_save ++;
-		}
+		g_hash_table_insert (priv->expanded_state, node->save_id, (gpointer)expanded);
 	}
 
 	/* if the node wasn't visible at present */
@@ -333,7 +359,7 @@ etree_set_expanded (ETreeModel *etm, ETreePath* node, gboolean expanded)
 
 		if (e_tree_model_node_is_visible (etm, node)) {
 			for (i = 0; i < node->visible_descendents; i ++) {
-				etm->row_array = g_array_remove_index (etm->row_array, row);
+				priv->row_array = g_array_remove_index (priv->row_array, row);
 				e_table_model_row_deleted (E_TABLE_MODEL (etm), row);
 			}
 		}
@@ -350,32 +376,35 @@ etree_set_expanded (ETreeModel *etm, ETreePath* node, gboolean expanded)
 	}
 }
 
+void
+e_tree_model_set_expanded_default (ETreeModel *etree,
+				   gboolean expanded)
+{
+	ETreeModelPriv *priv = etree->priv;
+
+	priv->expanded_default = expanded;
+}
+
 /* fairly naive implementation */
 static void
 etree_set_expanded_recurse (ETreeModel *etm, ETreePath* node, gboolean expanded)
 {
-	ETreePath **paths;
-	guint num_children;
-	int i;
+	ETreePath *child;
 
 	e_tree_model_node_set_expanded (etm, node, expanded);
 
-	num_children = e_tree_model_node_get_children (etm, node, &paths);
-	if (num_children) {
-		for (i = 0; i < num_children; i ++) {
-			e_tree_model_node_set_expanded_recurse (etm, paths[i], expanded);
-		}
-
-		g_free (paths);
-	}
+	for (child = node->first_child; child; child = child->next_sibling)
+		e_tree_model_node_set_expanded_recurse (etm, child, expanded);
 }
 
 static ETreePath *
 etree_node_at_row (ETreeModel *etree, int row)
 {
-	g_return_val_if_fail (row < etree->row_array->len, NULL);
+	ETreeModelPriv *priv = etree->priv;
 
-	return g_array_index (etree->row_array, ETreePath*, row);
+	g_return_val_if_fail (row < priv->row_array->len, NULL);
+
+	return g_array_index (priv->row_array, ETreePath*, row);
 }
 
 
@@ -417,7 +446,8 @@ static int
 etable_row_count (ETableModel *etm)
 {
 	ETreeModel *tree = E_TREE_MODEL (etm);
-	return tree->row_array->len;
+	ETreeModelPriv *priv = tree->priv;
+	return priv->row_array->len;
 }
 
 static void *
@@ -474,15 +504,16 @@ static const char *
 etable_row_sort_group(ETableModel *etm, int row)
 {
 	ETreeModel *etree = E_TREE_MODEL(etm);
+	ETreeModelPriv *priv = etree->priv;
 	ETreePath* node = e_tree_model_node_at_row (etree, row);
 
 	g_return_val_if_fail (node, "");
 
-	g_string_truncate(etree->sort_group, 0);
+	g_string_truncate(priv->sort_group, 0);
 	if (node)
-		build_sort_group(etree->sort_group, node);
+		build_sort_group(priv->sort_group, node);
 
-	return etree->sort_group->str;
+	return priv->sort_group->str;
 }
 
 static gboolean
@@ -586,8 +617,7 @@ static void
 e_tree_init (GtkObject *object)
 {
 	ETreeModel *etree = (ETreeModel *)object;
-
-	etree->sort_group = g_string_new("");
+	e_tree_model_construct (etree);
 }
 
 E_MAKE_TYPE(e_tree_model, "ETreeModel", ETreeModel, e_tree_model_class_init, e_tree_init, PARENT_TYPE)
@@ -667,13 +697,20 @@ e_tree_model_node_expanded  (ETreeModel *tree_model, ETreePath *node, gboolean *
 }
 
 
+
 void
 e_tree_model_construct (ETreeModel *etree)
 {
-	etree->root = NULL;
-	etree->root_visible = TRUE;
-	etree->row_array = g_array_new (FALSE, FALSE, sizeof(ETreePath*));
-	etree->expanded_state = g_hash_table_new (g_str_hash, g_str_equal);
+	ETreeModelPriv *priv = g_new0 (ETreeModelPriv, 1);
+
+	etree->priv = priv;
+
+	priv->node_chunk = g_mem_chunk_create (ETreePath, TREEPATH_CHUNK_AREA_SIZE, G_ALLOC_AND_FREE);
+	priv->root = NULL;
+	priv->root_visible = TRUE;
+	priv->row_array = g_array_new (FALSE, FALSE, sizeof(ETreePath*));
+	priv->expanded_state = g_hash_table_new (g_str_hash, g_str_equal);
+	priv->sort_group = g_string_new("");
 }
 
 ETreeModel *
@@ -707,10 +744,11 @@ e_tree_model_icon_of_node (ETreeModel *etree, ETreePath *path)
 int
 e_tree_model_row_of_node (ETreeModel *etree, ETreePath *node)
 {
+	ETreeModelPriv *priv = etree->priv;
 	int i;
 
-	for (i = 0; i < etree->row_array->len; i ++)
-		if (g_array_index (etree->row_array, ETreePath*, i) == node)
+	for (i = 0; i < priv->row_array->len; i ++)
+		if (g_array_index (priv->row_array, ETreePath*, i) == node)
 			return i;
 
 	return -1;
@@ -719,16 +757,18 @@ e_tree_model_row_of_node (ETreeModel *etree, ETreePath *node)
 void
 e_tree_model_root_node_set_visible (ETreeModel *etm, gboolean visible)
 {
-	if (visible != etm->root_visible) {
-		etm->root_visible = visible;
-		if (etm->root) {
+	ETreeModelPriv *priv = etm->priv;
+
+	if (visible != priv->root_visible) {
+		priv->root_visible = visible;
+		if (priv->root) {
 			if (visible) {
-				etm->row_array = g_array_insert_val (etm->row_array, 0, etm->root);
+				priv->row_array = g_array_insert_val (priv->row_array, 0, priv->root);
 			}
 			else {
 				ETreePath *root_path = e_tree_model_get_root (etm);
 				e_tree_model_node_set_expanded (etm, root_path, TRUE);
-				etm->row_array = g_array_remove_index (etm->row_array, 0);
+				priv->row_array = g_array_remove_index (priv->row_array, 0);
 			}
 			
 			e_table_model_changed (E_TABLE_MODEL (etm));
@@ -739,7 +779,8 @@ e_tree_model_root_node_set_visible (ETreeModel *etm, gboolean visible)
 gboolean
 e_tree_model_root_node_is_visible (ETreeModel *etm)
 {
-	return etm->root_visible;
+	ETreeModelPriv *priv = etm->priv;
+	return priv->root_visible;
 }
 
 ETreePath *
@@ -849,20 +890,33 @@ e_tree_model_node_insert (ETreeModel *tree_model,
 			  int position,
 			  gpointer node_data)
 {
+	ETreeModelPriv *priv;
 	ETreePath *new_path;
-	g_return_val_if_fail (parent_path != NULL || tree_model->root == NULL, NULL);
 
-	new_path = g_new0 (ETreePath, 1);
+	priv = tree_model->priv;
+
+	g_return_val_if_fail (parent_path != NULL || priv->root == NULL, NULL);
+
+	priv = tree_model->priv;
+
+	new_path = g_chunk_new0 (ETreePath, priv->node_chunk);
 
 	new_path->expanded = FALSE;
 	new_path->node_data = node_data;
 
 	if (parent_path != NULL) {
 
+		if (parent_path->first_child == NULL
+		    && !parent_path->expanded_set) {
+			e_tree_model_node_set_expanded (tree_model,
+							parent_path,
+							priv->expanded_default);
+		}
+
 		e_tree_path_insert (parent_path, position, new_path);
 
 		if (e_tree_model_node_is_visible (tree_model, new_path)) {
-			int parent_row;
+			int parent_row, child_offset = 0;
 			ETreePath *n;
 
 			/* we need to iterate back up to the root, incrementing the number of visible
@@ -871,28 +925,54 @@ e_tree_model_node_insert (ETreeModel *tree_model,
 				n->visible_descendents ++;
 			}
 				
-			/* finally, insert a row into the table */
-			if (position == -1)
+			/* determine if we are inserting at the end of this parent */
+			if (position == -1 || position == parent_path->num_children) {
 				position = e_tree_model_node_num_visible_descendents (tree_model, parent_path) - 1;
+			} else {
+				/* if we're not inserting at the end of the array, position is the child node we're
+				   inserting at, not the absolute row position - need to count expanded nodes before it too */
+				int i = position;
 
-			parent_row = e_tree_model_row_of_node (tree_model, parent_path);
+				n = e_tree_model_node_get_first_child(tree_model, parent_path);
+				while (n != NULL && i > 0) {
+					child_offset += n->visible_descendents;
+					n = n->next_sibling;
+					i--;
+				}
+			}
 
-			tree_model->row_array = g_array_insert_val (tree_model->row_array,
-								    parent_row + position + 1, new_path);
 
-			e_table_model_row_inserted (E_TABLE_MODEL(tree_model), parent_row + position + 1);
+			/* if the parent is the root, no need to search for its position since it aint there */
+			if (parent_path->parent == NULL) {
+				parent_row = -1;
+			} else {
+				parent_row = e_tree_model_row_of_node (tree_model, parent_path);
+			}
+
+			e_table_model_pre_change(E_TABLE_MODEL(tree_model));
+
+			priv->row_array = g_array_insert_val (priv->row_array,
+							      parent_row + position + 1 + child_offset, new_path);
+
+			/* only do this if we know a changed signal isn't coming later on */
+			if (!priv->frozen)
+				e_table_model_row_inserted (E_TABLE_MODEL(tree_model), parent_row + position + 1 + child_offset);
 		}
+
+		if (parent_path->compare)
+			e_tree_model_node_sort (tree_model, parent_path);
 	}
 	else {
-		tree_model->root = new_path;
-		if (tree_model->root_visible) {
-			tree_model->row_array = g_array_insert_val (tree_model->row_array, 0, tree_model->root);
+		priv->root = new_path;
+		if (priv->root_visible) {
+			priv->row_array = g_array_insert_val (priv->row_array, 0, priv->root);
 			e_table_model_row_inserted (E_TABLE_MODEL (tree_model), 0);
 		}
 		else {
 			/* need to mark the new node as expanded or
                            we'll never see it's children */
 			new_path->expanded = TRUE;
+			new_path->expanded_set = TRUE;
 		}
 	}
 
@@ -930,64 +1010,113 @@ e_tree_model_node_insert_before (ETreeModel *etree,
 	return e_tree_model_node_insert (etree, parent, position, node_data);
 }
 
-static gboolean
-child_remove (ETreeModel *model, ETreePath *node, gpointer data)
+/* just blows away child data, doesn't take into account unlinking/etc */
+static void
+child_free(ETreeModel *etree, ETreePath *node)
 {
-	e_tree_model_node_remove (model, node);
-	return FALSE;
+	ETreePath *child, *next;
+	ETreeModelPriv *priv = etree->priv;
+
+	child = node->first_child;
+	while (child) {
+		next = child->next_sibling;
+		child_free(etree, child);
+		child = next;
+	}
+
+	if (node->save_id) {
+		g_hash_table_remove(priv->expanded_state, node->save_id);
+		g_free(node->save_id);
+	}
+	g_chunk_free(node, priv->node_chunk);
 }
 
 gpointer
 e_tree_model_node_remove (ETreeModel *etree, ETreePath *path)
 {
+	ETreeModelPriv *priv = etree->priv;
 	ETreePath *parent = path->parent;
 	gpointer ret = path->node_data;
+	int row, visible = 0, base = 0;
+	gboolean dochanged;
 
-	/* remove children */
-	e_tree_model_node_traverse (etree, path, child_remove, etree);
-
-	/* clean up the display */
+	/* work out what range of visible rows to remove */
 	if (parent) {
-		if (e_tree_model_node_is_visible (etree, path)) {
-			int row = e_tree_model_row_of_node (etree, path);
-			e_table_model_row_deleted (E_TABLE_MODEL (etree), row);
-			etree->row_array = g_array_remove_index (etree->row_array, row);
-
-			/* we need to iterate back up to the root, incrementing the number of visible
-			   descendents */
-			for (; parent; parent = parent->parent) {
-				parent->visible_descendents --;
-			}
+		if (e_tree_model_node_is_visible(etree, path)) {
+			base = e_tree_model_row_of_node(etree, path);
+			visible = path->visible_descendents + 1;
 		}
-	}
-	else if (path == etree->root) {
-		etree->root = NULL;
-		if (etree->root_visible) {
-			etree->row_array = g_array_remove_index (etree->row_array, 0);
-			e_table_model_row_deleted (E_TABLE_MODEL (etree), 0);
+	} else if (path == priv->root) {
+		priv->root = NULL;
+		if (priv->root_visible) {
+			base = 0;
+			visible = path->visible_descendents + 1;
+		} else {
+			base = 0;
+			visible = path->visible_descendents;
 		}
-	}
-	else {
-		/* XXX invalid path */
+	} else {
+		g_warning("Trying to remove invalid path %p", path);
 		return NULL;
 	}
 
-	/* unlink the node */
+	/* unlink this node - we only have to unlink the root node being removed,
+	   since the others are only references from this node */
 	e_tree_path_unlink (path);
 
-	/* now free up the storage from that path */
-	g_free (path);
+	/*printf("removing %d nodes from position %d\n", visible, base);*/
+
+	if (visible > 0) {
+		/* fix up the parent visible counts */
+		for (; parent; parent = parent->parent) {
+			parent->visible_descendents -= visible;
+		}
+
+		/* if we have a lot of nodes to remove, then we dont row_deleted each one */
+		/* could probably be tuned, but this'll do, since its normally only when we
+		   remove the whole lot do we really care */
+		dochanged = (visible > 1000) || (visible > (priv->row_array->len / 4));
+
+		e_table_model_pre_change(E_TABLE_MODEL (etree));
+
+		/* and physically remove them */
+		if (visible == priv->row_array->len) {
+			g_array_set_size(priv->row_array, 0);
+		} else {
+			memmove(&g_array_index(priv->row_array, ETreePath *, base),
+				&g_array_index(priv->row_array, ETreePath *, base+visible),
+				(priv->row_array->len - (base+visible)) * sizeof(ETreePath *));
+			g_array_set_size(priv->row_array, priv->row_array->len - visible);
+		}
+
+		/* tell the system we've removed (these) nodes */
+		if (!priv->frozen) {
+			if (dochanged) {
+				e_table_model_changed(E_TABLE_MODEL(etree));
+			} else {
+				for (row=visible-1;row>=0;row--) {
+					e_table_model_row_deleted(E_TABLE_MODEL(etree), row+base);
+				}
+			}
+		}
+	}
+
+	child_free(etree, path);
 
 	return ret;
 }
 
-
 static void
 add_visible_descendents_to_array (ETreeModel *etm, ETreePath *node, int *row, int *count)
 {
+	ETreeModelPriv *priv = etm->priv;
+
 	/* add a row for this node */
-	etm->row_array = g_array_insert_val (etm->row_array, (*row), node);
-	e_table_model_row_inserted (E_TABLE_MODEL (etm), (*row)++);
+	e_table_model_pre_change(E_TABLE_MODEL (etm));
+	priv->row_array = g_array_insert_val (priv->row_array, (*row), node);
+	if (!priv->frozen)
+		e_table_model_row_inserted (E_TABLE_MODEL (etm), (*row));
+	(*row) ++;
 	(*count) ++;
 
 	/* then loop over its children, calling this routine for each
@@ -1021,17 +1150,17 @@ e_tree_model_save_expanded_state (ETreeModel *etm, const char *filename)
 	int fd, rv;
 	xmlChar *buf;
 	int buf_size;
-	gboolean save_expanded = etm->num_expanded_to_save < etm->num_collapsed_to_save;
-
-	g_print ("saving expanded state: %d expanded, %d collapsed, should save %s\n",
-		 etm->num_expanded_to_save, etm->num_collapsed_to_save,
-		 save_expanded ? "expanded" : "collapsed");
+	ETreeModelPriv *priv = etm->priv;
 
 	doc = xmlNewDoc ((xmlChar*) "1.0");
-	root = xmlNewDocNode (doc, NULL, (xmlChar *) save_expanded ? "expanded_state" : "collapsed_state", NULL);
+	root = xmlNewDocNode (doc, NULL,
+			      (xmlChar *) "expanded_state",
+			      NULL);
 	xmlDocSetRootElement (doc, root);
 
-	g_hash_table_foreach (etm->expanded_state, (GHFunc)save_expanded_state_func, root);
+	g_hash_table_foreach (priv->expanded_state,
+			      (GHFunc)save_expanded_state_func,
+			      root);
 
 	fd = open (filename, O_CREAT | O_TRUNC | O_WRONLY, 0777);
 
@@ -1081,6 +1210,7 @@ get_string_value (xmlNode *node,
 gboolean
 e_tree_model_load_expanded_state (ETreeModel *etm, const char *filename)
 {
+	ETreeModelPriv *priv = etm->priv;
 	xmlDoc *doc;
 	xmlNode *root;
 	xmlNode *child;
@@ -1090,7 +1220,7 @@ e_tree_model_load_expanded_state (ETreeModel *etm, const char *filename)
 		return FALSE;
 
 	root = xmlDocGetRootElement (doc);
-	if (root == NULL || strcmp (root->name, "expanded_state") != 0) {
+	if (root == NULL || strcmp (root->name, "expanded_state")) {
 		xmlFreeDoc (doc);
 		return FALSE;
 	}
@@ -1105,7 +1235,7 @@ e_tree_model_load_expanded_state (ETreeModel *etm, const char *filename)
 
 		id = get_string_value (child, "id");
 
-		g_hash_table_insert (etm->expanded_state, id, (gpointer)TRUE);
+		g_hash_table_insert (priv->expanded_state, id, (gpointer)TRUE);
 	}
 
 	xmlFreeDoc (doc);
@@ -1119,33 +1249,26 @@ e_tree_model_node_set_save_id (ETreeModel *etm, ETreePath *node, const char *id)
 {
 	char *key;
 	gboolean expanded_state;
+	ETreeModelPriv *priv;
 
 	g_return_if_fail (E_TREE_MODEL (etm));
 	g_return_if_fail (node);
 
-	if (g_hash_table_lookup_extended (etm->expanded_state,
+	priv = etm->priv;
+
+	if (g_hash_table_lookup_extended (priv->expanded_state,
 					  id, (gpointer*)&key, (gpointer*)&expanded_state)) {
 
 		e_tree_model_node_set_expanded (etm, node,
 						expanded_state);
 
-		if (expanded_state)
-			etm->num_expanded_to_save ++;
-		else
-			etm->num_collapsed_to_save ++;
-
 		/* important that this comes after the e_tree_model_node_set_expanded */
 		node->save_id = key;
 	}
 	else {
 		node->save_id = g_strdup (id);
 
-		g_hash_table_insert (etm->expanded_state, node->save_id, (gpointer)node->expanded);
-
-		if (node->expanded)
-			etm->num_expanded_to_save ++;
-		else
-			etm->num_collapsed_to_save ++;
+		g_hash_table_insert (priv->expanded_state, node->save_id, (gpointer)node->expanded);
 	}
 }
 
@@ -1191,7 +1314,8 @@ e_tree_model_node_sort (ETreeModel *tree_model,
 	int i;
 	int child_index;
 	gboolean node_expanded = e_tree_model_node_is_expanded (tree_model, node);
-	
+	ETreeModelPriv *priv = tree_model->priv;;
+
 	g_return_if_fail (E_TREE_MODEL (tree_model));
 	g_return_if_fail (node);
 
@@ -1200,6 +1324,8 @@ e_tree_model_node_sort (ETreeModel *tree_model,
 	if (num_nodes == 0)
 		return;
 
+	e_table_model_pre_change(E_TABLE_MODEL (tree_model));
+
 	sort_info = g_new (ETreeSortInfo, num_nodes);
 
 	child_index = e_tree_model_row_of_node (tree_model, node) + 1;
@@ -1213,7 +1339,7 @@ e_tree_model_node_sort (ETreeModel *tree_model,
 
 		e_tree_model_node_set_expanded(tree_model, sort_info[i].path, FALSE);
 		if (node_expanded)
-			tree_model->row_array = g_array_remove_index (tree_model->row_array, child_index);
+			priv->row_array = g_array_remove_index (priv->row_array, child_index);
 		e_tree_path_unlink (sort_info[i].path);
 	}
 
@@ -1224,8 +1350,8 @@ e_tree_model_node_sort (ETreeModel *tree_model,
 	for (i = 0; i < num_nodes; i ++) {
 		e_tree_path_insert (node, i, sort_info[i].path);
 		if (node_expanded)
-			tree_model->row_array = g_array_insert_val (tree_model->row_array, child_index + i,
-								    sort_info[i].path);
+			priv->row_array = g_array_insert_val (priv->row_array, child_index + i,
+							      sort_info[i].path);
 	}
 
 	/* make another pass expanding the children as needed.  
@@ -1239,6 +1365,7 @@ e_tree_model_node_sort (ETreeModel *tree_model,
 
 	g_free (sort_info);
 
-	e_table_model_changed (E_TABLE_MODEL (tree_model));
+	if (!priv->frozen)
+		e_table_model_changed (E_TABLE_MODEL (tree_model));
 }
 
