@@ -51,6 +51,8 @@ gchar **e_strsplit (const gchar *string,
 gchar *e_strstrcase (const gchar *haystack,
 		     const gchar *needle);
 
+void e_filename_make_safe (gchar *string);
+
 void e_marshal_INT__INT_INT_POINTER (GtkObject * object,
 				     GtkSignalFunc func,
 				     gpointer func_data, GtkArg * args);
@@ -90,4 +92,9 @@ void e_marshal_NONE__INT_INT_POINTER_INT_INT_POINTER_INT_INT (GtkObject * object
 							      gpointer func_data,
 							      GtkArg * args);
 
+void e_marshal_NONE__POINTER_POINTER_INT (GtkObject * object,
+					  GtkSignalFunc func,
+					  gpointer func_data,
+					  GtkArg * args);
+
 #endif /* _E_UTIL_H_ */
