@@ -28,41 +28,6 @@ typedef struct {
 	char *name;	/* english name - eg. "white" */
 } ColorNamePair;
 
-struct _ColorPalette {
-	GtkVBox          vbox;
-	GtkTooltips      *tool_tip;
-	GnomeColorPicker *picker;
-	/*
-	 * Array of colors
-	 */
-	GnomeCanvasItem **items;
-	/* The (potentially NULL) default color */
-        GdkColor *default_color;
-        /*
-	 * Position of the last possible position
-	 * for custom colors in **items
-	 * (i.e. custom colors go from items[custom_color_pos]
-	 *  to items[total - 1])
-	 *
-	 * If custom_color_pos == -1, there is no room for custom colors
-	 */
-        int custom_color_pos;
-        /*
-	 * Number of default colors in **items
-	 */
-	int total;
-
-	/* The color group to which we belong */
-	ColorGroup *color_group;
-};
-
-typedef struct {
-	GtkVBoxClass parent_class;
-	
-	/* Signals emited by this widget */
-	void (* changed) (ColorPalette *color_palette, GdkColor *color, gboolean custom);
-} ColorPaletteClass;
-
 static gint color_palette_signals [LAST_SIGNAL] = { 0, };
 
 static GtkObjectClass *color_palette_parent_class;
@@ -160,10 +125,10 @@ static void
 emit_change (ColorPalette *P, GdkColor *color, gboolean custom, gboolean tell_group)
 {
 	if (tell_group)
-		color_group_add_color( P->color_group, color, custom);
+		color_group_add_color (P->color_group, color, custom);
 	else
-  	gtk_signal_emit (
-		GTK_OBJECT (P), color_palette_signals [CHANGED], color, custom);
+		gtk_signal_emit (
+			GTK_OBJECT (P), color_palette_signals [CHANGED], color, custom);
 	
 }
 
@@ -175,7 +140,7 @@ emit_change (ColorPalette *P, GdkColor *color, gboolean custom, gboolean tell_gr
  * Also take care of setting up the GnomeColorPicker 'display'
  */
 static void
-color_palette_change_custom_color ( ColorPalette *P, GdkColor *new)
+color_palette_change_custom_color (ColorPalette *P, GdkColor *new)
 {
 	int index;
 	GnomeCanvasItem *item;
@@ -195,27 +160,27 @@ color_palette_change_custom_color ( ColorPalette *P, GdkColor *new)
 		item = P->items [index];
 		next_item = P->items [index + 1];
 		
-		gtk_object_get ( GTK_OBJECT (next_item),
-				 "fill_color_gdk", &color,
-				 "outline_color_gdk", &outline,
-				 NULL);
-		gnome_canvas_item_set ( item,
-					"fill_color_gdk", color,
-					"outline_color_gdk", outline,
-					NULL);
+		gtk_object_get (GTK_OBJECT (next_item),
+				"fill_color_gdk", &color,
+				"outline_color_gdk", &outline,
+				NULL);
+		gnome_canvas_item_set (item,
+				       "fill_color_gdk", color,
+				       "outline_color_gdk", outline,
+				       NULL);
 		g_free (color);
 		g_free (outline);
 	}
 	item = P->items [index];
-	gnome_canvas_item_set ( item,
-				"fill_color_gdk", new,
-				"outline_color_gdk", new,
-				NULL);
-	gnome_color_picker_set_i16 ( P->picker,
-				     new->red,
-				     new->green,
-				     new->blue,
-				     0);
+	gnome_canvas_item_set (item,
+			       "fill_color_gdk", new,
+			       "outline_color_gdk", new,
+			       NULL);
+	gnome_color_picker_set_i16 (P->picker,
+				    new->red,
+				    new->green,
+				    new->blue,
+				    0);
 	return;
 }
 
@@ -353,11 +318,11 @@ custom_color_history_setup(ColorPalette *P)
 	g_return_if_fail (P != NULL);
 	g_return_if_fail (P->color_group != NULL);
 	
-	for ( color = color_group_oldest_color (P->color_group);
-	      color != NULL ;
-	      color = color_group_previous_color(P->color_group)) 
-		color_palette_change_custom_color (P , color);
-	
+	for (color = color_group_oldest_color (P->color_group);
+	     color != NULL ;
+	     color = color_group_previous_color(P->color_group)) 
+	    color_palette_change_custom_color (P , color);
+
 	return;
 }
 
@@ -444,7 +409,7 @@ color_palette_setup (ColorPalette *P,
 	
 	
 	/* "Custom" color - we'll pop up a GnomeColorPicker */
-	cust_label = gtk_label_new ( _("Custom Color:"));
+	cust_label = gtk_label_new (_("Custom Color:"));
 	gtk_table_attach (GTK_TABLE (table), cust_label, 0, ncols - 3 ,
 			  row + 1, row + 2, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 	/*
@@ -513,10 +478,10 @@ color_palette_construct (ColorPalette *P,
  *
  */
 static GtkWidget*
-color_palette_new_with_vals ( char const * const no_color_label,
-			      int ncols, int nrows, ColorNamePair *color_names,
-			      GdkColor *default_color, 
-			      const gchar *group_name){
+color_palette_new_with_vals (char const * const no_color_label,
+			     int ncols, int nrows, ColorNamePair *color_names,
+			     GdkColor *default_color, 
+			     const gchar *group_name){
 	ColorPalette *P;
 	
 	g_return_val_if_fail (color_names != NULL, NULL);
@@ -529,7 +494,7 @@ color_palette_new_with_vals ( char const * const no_color_label,
 	color_palette_construct (P, no_color_label, ncols, nrows, color_names);
 	custom_color_history_setup(P);
 	
-	gtk_signal_connect( GTK_OBJECT(P->color_group), "color_change",
+	gtk_signal_connect (GTK_OBJECT(P->color_group), "color_change",
 			    GTK_SIGNAL_FUNC (cb_group_color_change),
 			    P);
 	
@@ -619,8 +584,8 @@ static ColorNamePair default_color_set [] = {
  *
  */
 GtkWidget*
-color_palette_new (  char const * const no_color_label,
-		     GdkColor *default_color, const gchar *group_name)
+color_palette_new (char const * const no_color_label,
+		   GdkColor *default_color, const gchar *group_name)
 {
 	/* specify 6 rows to allow for a row of custom colors */
 	return color_palette_new_with_vals (no_color_label,
