@@ -14,7 +14,7 @@
 
 #include <glib.h>
 #include <gdk/gdk.h>
-#include <unicode.h>
+#include <iconv.h>
 #include <libgnome/gnome-defs.h>
 
 BEGIN_GNOME_DECLS
@@ -40,6 +40,8 @@ void e_font_unref (EFont *font);
 gint e_font_ascent (EFont * font);
 gint e_font_descent (EFont * font);
 
+gchar *e_font_get_name (EFont *font);
+
 #define e_font_height(f) (e_font_ascent (f) + e_font_descent (f))
 
 /*
@@ -61,8 +63,8 @@ int e_font_utf8_char_width (EFont *font, EFontStyle style,
 			    char *text);
 
 const gchar *e_gdk_font_encoding (GdkFont *font);
-unicode_iconv_t e_uiconv_from_gdk_font (GdkFont *font);
-unicode_iconv_t e_uiconv_to_gdk_font (GdkFont *font);
+iconv_t e_iconv_from_gdk_font (GdkFont *font);
+iconv_t e_iconv_to_gdk_font (GdkFont *font);
 
 END_GNOME_DECLS
 
