@@ -4,17 +4,17 @@
  * Authors:
  *   Miguel de Icaza (miguel@kernel.org)
  *   Dom Lachowicz (dominicl@seas.upenn.edu)
+ *
  * Reworked and split up into a separate ColorPalette object:
  *   Michael Levy (mlevy@genoscope.cns.fr)
  *
  */
 #include <config.h>
+#include "widget-color-combo.h"
+
 #include <gnome.h>
 #include <gtk/gtkentry.h>
 #include <libgnomeui/gnome-canvas.h>
-#include "gtk-combo-box.h"
-#include "widget-color-combo.h"
-#include "color-palette.h"
 #include "e-colors.h"
 
 enum {
@@ -22,27 +22,6 @@ enum {
 	LAST_SIGNAL
 };
 
-struct _ColorCombo {
-	GtkComboBox     combo_box;
-
-	/*
-	 * Canvas where we display
-	 */
-	GtkWidget       *preview_button;
-	GnomeCanvas     *preview_canvas;
-	GnomeCanvasItem *preview_color_item;
-	ColorPalette    *palette;
-
-        GdkColor *default_color;
-};
-
-typedef struct {
-	GnomeCanvasClass parent_class;
-
-	/* Signals emited by this widget */
-	void (* changed) (ColorCombo *color_combo, GdkColor *color);
-} ColorComboClass;
-
 static gint color_combo_signals [LAST_SIGNAL] = { 0, };
 
 static GtkObjectClass *color_combo_parent_class;
@@ -129,7 +108,7 @@ emit_change (ColorCombo *cc, GdkColor *color)
 static void
 cb_color_change (ColorPalette *P, GdkColor *color, gboolean custom, ColorCombo *cc)
 {
-	set_color(cc, color);
+	set_color (cc, color);
 	emit_change (cc, color);
 }
 
@@ -153,7 +132,7 @@ cb_cust_color_clicked (GtkWidget *widget, ColorCombo *cc)
 static void
 color_table_setup (ColorCombo *cc, char const * const no_color_label, gchar *group_name)
 {
-	g_return_if_fail(cc != NULL);
+	g_return_if_fail (cc != NULL);
 
 	/* Tell the palette that we will be changing it's custom colors */
 	cc->palette = 
@@ -170,7 +149,7 @@ color_table_setup (ColorCombo *cc, char const * const no_color_label, gchar *gro
 	gtk_signal_connect (GTK_OBJECT (cc->palette), "changed",
 			    GTK_SIGNAL_FUNC (cb_color_change), cc);
 
-	gtk_widget_show_all (GTK_WIDGET(cc->palette));
+	gtk_widget_show_all (GTK_WIDGET (cc->palette));
 
 	return;
 }
@@ -205,51 +184,51 @@ color_combo_construct (ColorCombo *cc, char **icon,
 	if (icon) {
 		image = gdk_imlib_create_image_from_xpm_data (icon);
 
-	gnome_canvas_item_new (
-		GNOME_CANVAS_GROUP (gnome_canvas_root (cc->preview_canvas)),
-		gnome_canvas_image_get_type (),
-		"image",  image,
-		"x",      0.0,
-		"y",      0.0,
-		"width",  (double) image->rgb_width,
-		"height", (double) image->rgb_height,
-		"anchor", GTK_ANCHOR_NW,
-		NULL);
-
-	cc->preview_color_item = gnome_canvas_item_new (
-		GNOME_CANVAS_GROUP (gnome_canvas_root (cc->preview_canvas)),
-		gnome_canvas_rect_get_type (),
-		"x1",         3.0,
-		"y1",         19.0,
-		"x2",         20.0,
-		"y2",         22.0,
-		"fill_color", "black",
-		"width_pixels", 1,
-		NULL);
+		gnome_canvas_item_new (
+			GNOME_CANVAS_GROUP (gnome_canvas_root (cc->preview_canvas)),
+			gnome_canvas_image_get_type (),
+			"image",  image,
+			"x",      0.0,
+			"y",      0.0,
+			"width",  (double) image->rgb_width,
+			"height", (double) image->rgb_height,
+			"anchor", GTK_ANCHOR_NW,
+			NULL);
+		
+		cc->preview_color_item = gnome_canvas_item_new (
+			GNOME_CANVAS_GROUP (gnome_canvas_root (cc->preview_canvas)),
+			gnome_canvas_rect_get_type (),
+			"x1",         3.0,
+			"y1",         19.0,
+			"x2",         20.0,
+			"y2",         22.0,
+			"fill_color", "black",
+			"width_pixels", 1,
+			NULL);
 	} else
 		cc->preview_color_item = gnome_canvas_item_new (
-								GNOME_CANVAS_GROUP (gnome_canvas_root (cc->preview_canvas)),
-								gnome_canvas_rect_get_type (),
-								"x1",         2.0,
-								"y1",         1.0,
-								"x2",         21.0,
-								"y2",         22.0,
-								"fill_color", "black",
-								"width_pixels", 1,
-								NULL);
-
+			GNOME_CANVAS_GROUP (gnome_canvas_root (cc->preview_canvas)),
+			gnome_canvas_rect_get_type (),
+			"x1",         2.0,
+			"y1",         1.0,
+			"x2",         21.0,
+			"y2",         22.0,
+			"fill_color", "black",
+			"width_pixels", 1,
+			NULL);
+	
 	gtk_container_add (GTK_CONTAINER (cc->preview_button), GTK_WIDGET (cc->preview_canvas));
 	gtk_widget_set_usize (GTK_WIDGET (cc->preview_canvas), 24, 24);
 	gtk_signal_connect (GTK_OBJECT (cc->preview_button), "clicked",
 			    GTK_SIGNAL_FUNC (preview_clicked), cc);
-
+	
 	/*
 	 * Our table selector
 	 */
 	color_table_setup (cc, no_color_label, group_name);
-
+	
 	gtk_widget_show_all (cc->preview_button);
-
+	
 	gtk_combo_box_construct (GTK_COMBO_BOX (cc),
 				 cc->preview_button,
 				 GTK_WIDGET (cc->palette));
