@@ -32,8 +32,6 @@
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gal/e-paned/e-hpaned.h>
-#include <gal/e-table/e-table-header.h>
-#include <gal/e-table/e-table-header-item.h>
 #include <gal/e-table/e-table-item.h>
 #include <gal/e-table/e-cell-text.h>
 #include <gal/e-table/e-cell-tree.h>
@@ -44,26 +42,8 @@
 #define MINI_ICON_SIZE 16
 
 #define RIGHT_COLS 4
-#define LEFT_COLS 4
-
-#define RIGHT_E_TABLE_SPEC \
-"<ETableSpecification>                    	                       \
-	<columns-shown>                  			       \
-		<column> 0 </column>     			       \
-		<column> 1 </column>     			       \
-		<column> 2 </column>     			       \
-		<column> 3 </column>     			       \
-	</columns-shown>                 			       \
-	<grouping></grouping>                                          \
-</ETableSpecification>"
-
-#define LEFT_E_TABLE_SPEC \
-"<ETableSpecification no-header=\"1\">         	                       \
-	<columns-shown>                  			       \
-		<column> 0 </column>     			       \
-	</columns-shown>                 			       \
-	<grouping></grouping>                                          \
-</ETableSpecification>"
+#define LEFT_COLS 1
+/* Virtual columns
 
 char *left_headers [LEFT_COLS] = {
   "Folder"
@@ -75,6 +55,31 @@ char *right_headers [RIGHT_COLS] = {
   "Type",
   "Mime Type"
 };
+*/
+
+#define RIGHT_E_TABLE_SPEC \
+"<ETableSpecification>                    	                       \
+  <ETableColumn model_col=\"0\" _title=\"Name\"      expansion=\"1.0\" minimum_width=\"20\" resizable=\"true\" cell=\"tree-string\" compare=\"string\"/> \
+  <ETableColumn model_col=\"1\" _title=\"Size\"      expansion=\"1.0\" minimum_width=\"20\" resizable=\"true\" cell=\"string\"      compare=\"string\"/> \
+  <ETableColumn model_col=\"2\" _title=\"Type\"      expansion=\"1.0\" minimum_width=\"20\" resizable=\"true\" cell=\"string\"      compare=\"string\"/> \
+  <ETableColumn model_col=\"3\" _title=\"Mime Type\" expansion=\"1.0\" minimum_width=\"20\" resizable=\"true\" cell=\"string\"      compare=\"string\"/> \
+        <ETableState> \
+	<column source=\"0\"/>     			       \
+	<column source=\"1\"/>     			       \
+	<column source=\"2\"/>     			       \
+	<column source=\"3\"/>     			       \
+	<grouping></grouping>                                          \
+        </ETableState>
+</ETableSpecification>"
+
+#define LEFT_E_TABLE_SPEC \
+"<ETableSpecification no-headers=\"true\" cursor-mode=\"line\"> \
+  <ETableColumn model_col=\"0\" _title=\"Folder\" expansion=\"1.0\" minimum_width=\"20\" resizable=\"true\" cell=\"cell_tree\"      compare=\"string\"/> \
+        <ETableState> \
+		<column source=\"0\"/>     			       \
+	        <grouping></grouping>                                          \
+        </ETableState>
+</ETableSpecification>"
 
 
 
@@ -441,10 +446,6 @@ create_right_tree(GtkWidget *paned)
 {
 	GtkWidget *e_table;
 	GtkWidget *frame;
-	ECell *cell_left_just;
-	ECell *cell_tree;
-	ETableHeader *e_table_header;
-	int i;
 
 	right_filter = gnome_vfs_directory_filter_new (GNOME_VFS_DIRECTORY_FILTER_NONE,
 						      GNOME_VFS_DIRECTORY_FILTER_NODIRS,
@@ -469,53 +470,6 @@ create_right_tree(GtkWidget *paned)
 					       0, NULL);
 	e_tree_model_root_node_set_visible (right_model, FALSE);
 
-	/*
-	 * Next we create a header.  The ETableHeader is used in two
-	 * different way.  The first is the full_header.  This is the
-	 * list of possible columns in the view.  The second use is
-	 * completely internal.  Many of the ETableHeader functions are
-	 * for that purpose.  The only functions we really need are
-	 * e_table_header_new and e_table_header_add_col.
-	 *
-	 * First we create the header.
-	 */
-	e_table_header = e_table_header_new ();
-	
-	/*
-	 * Next we have to build renderers for all of the columns.
-	 * Since all our columns are text columns, we can simply use
-	 * the same renderer over and over again.  If we had different
-	 * types of columns, we could use a different renderer for
-	 * each column.
-	 */
-	cell_left_just = e_cell_text_new (E_TABLE_MODEL(right_model), NULL, GTK_JUSTIFY_LEFT);
-
-	/* 
-	 * This renderer is used for the tree column (the leftmost one), and
-	 * has as its subcell renderer the text renderer.  this means that
-	 * text is displayed to the right of the tree pipes.
-	 */
-	cell_tree = e_cell_tree_new (E_TABLE_MODEL(right_model),
-				     NULL, NULL,
-				     TRUE, cell_left_just);
-
-	/*
-	 * Next we create a column object for each view column and add
-	 * them to the header.  We don't create a column object for
-	 * the importance column since it will not be shown.
-	 */
-	for (i = 0; i < RIGHT_COLS; i++) {
-		/* Create the column. */
-		ETableCol *ecol = e_table_col_new (
-						   i, right_headers [i],
-						   80, 20,
-						   i == 0 ? cell_tree
-						   : cell_left_just,
-						   g_str_compare, TRUE);
-		/* Add it to the header. */
-		e_table_header_add_column (e_table_header, ecol, i);
-	}
-
 	/* This frame is simply to get a bevel around our table. */
 	frame = gtk_frame_new (NULL);
 
@@ -524,7 +478,7 @@ create_right_tree(GtkWidget *paned)
 	 * the table we've created, the header, the model, and the
 	 * initial layout.  It does the rest.
 	 */
-	e_table = e_table_scrolled_new (e_table_header, E_TABLE_MODEL(right_model), RIGHT_E_TABLE_SPEC);
+	e_table = e_table_scrolled_new (E_TABLE_MODEL(right_model), NULL, RIGHT_E_TABLE_SPEC, NULL);
 
 	gtk_signal_connect (GTK_OBJECT (e_table), "double_click", GTK_SIGNAL_FUNC (on_double_click), NULL);
 
@@ -542,12 +496,8 @@ create_left_tree (GtkWidget *paned, char *root_uri)
 	GtkWidget *scrolled;
 	GtkWidget *e_table;
 	GtkWidget *frame;
-	ECell *cell_left_just;
-	ECell *cell_tree;
-	ETableHeader *e_table_header;
 	ETreePath *root_node;
 	VFSInfo *root_vfs_info;
-	ETableCol *ecol;
 
 	left_filter = gnome_vfs_directory_filter_new (GNOME_VFS_DIRECTORY_FILTER_NONE,
 						      /* putting DIRSONLY doesn't work here, so we filter
@@ -597,44 +547,6 @@ create_left_tree (GtkWidget *paned, char *root_uri)
 
 	e_tree_model_root_node_set_visible (left_model, TRUE);
 
-	/*
-	 * Next we create a header.  The ETableHeader is used in two
-	 * different way.  The first is the full_header.  This is the
-	 * list of possible columns in the view.  The second use is
-	 * completely internal.  Many of the ETableHeader functions are
-	 * for that purpose.  The only functions we really need are
-	 * e_table_header_new and e_table_header_add_col.
-	 *
-	 * First we create the header.
-	 */
-	e_table_header = e_table_header_new ();
-	
-	/*
-	 * Next we have to build renderers for all of the columns.
-	 * Since all our columns are text columns, we can simply use
-	 * the same renderer over and over again.  If we had different
-	 * types of columns, we could use a different renderer for
-	 * each column.
-	 */
-	cell_left_just = e_cell_text_new (E_TABLE_MODEL(left_model), NULL, GTK_JUSTIFY_LEFT);
-
-	/* 
-	 * This renderer is used for the tree column (the leftmost one), and
-	 * has as its subcell renderer the text renderer.  this means that
-	 * text is displayed to the right of the tree pipes.
-	 */
-	cell_tree = e_cell_tree_new (E_TABLE_MODEL(left_model),
-				     NULL, NULL,
-				     TRUE, cell_left_just);
-
-	/* Create the column. */
-	ecol = e_table_col_new (0, left_headers [0],
-				80, 20,
-				cell_tree,
-				g_str_compare, TRUE);
-	
-	e_table_header_add_column (e_table_header, ecol, 0);
-
 	/* This frame is simply to get a bevel around our table. */
 	frame = gtk_frame_new (NULL);
 
@@ -643,11 +555,7 @@ create_left_tree (GtkWidget *paned, char *root_uri)
 	 * the table we've created, the header, the model, and the
 	 * initial layout.  It does the rest.
 	 */
-	e_table = e_table_new (e_table_header, E_TABLE_MODEL(left_model), LEFT_E_TABLE_SPEC);
-
-	gtk_object_set (GTK_OBJECT (e_table),
-			"cursor_mode", E_TABLE_CURSOR_LINE,
-			NULL);
+	e_table = e_table_new (E_TABLE_MODEL(left_model), NULL, LEFT_E_TABLE_SPEC, NULL);
 
 	scrolled = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
